@@ -60,7 +60,7 @@ void ImageLoaderOutputDevice::drawImage(GfxState *state, Object *ref, Stream *st
         return;
     }
 
-    if (ref->isRef() && d->m_refNum != ref->getRef().num) {
+    if (ref->isRef() && d->refNum() != ref->getRef().num) {
         return;
     }
 
@@ -80,6 +80,22 @@ static inline bool isColor(GfxRGB rgb)
 
 QImage PdfImagePrivate::load(Stream* str, GfxImageColorMap* colorMap)
 {
+    if (m_format == QImage::Format_Mono) { // bitmasks are not stored as image streams
+        auto img = QImage(m_sourceWidth, m_sourceHeight, QImage::Format_Mono); // TODO implicit Format_Grayscale8 conversion
+        str->reset();
+        const int rowSize = (m_sourceWidth + 7) / 8;
+        for (int y = 0; y < m_sourceHeight; ++y) {
+            auto imgData = img.scanLine(y);
+            for (int x = 0; x < rowSize; x++) {
+                const auto c = str->getChar();
+                *imgData++ = c ^ 0xff;
+            }
+        }
+
+        m_page->m_doc->m_imageData[m_ref] = img;
+        return img;
+    }
+
     auto img = QImage(m_sourceWidth, m_sourceHeight, (m_loadingHints & PdfImage::ConvertToGrayscaleHint) ? QImage::Format_Grayscale8 : m_format);
     const auto bytesPerPixel = colorMap->getNumPixelComps();
     std::unique_ptr<ImageStream> imgStream(new ImageStream(str, m_sourceWidth, bytesPerPixel, colorMap->getBits()));
@@ -122,13 +138,13 @@ QImage PdfImagePrivate::load(Stream* str, GfxImageColorMap* colorMap)
     }
     imgStream->close();
 
-    m_page->m_doc->m_imageData[m_refNum] = img;
+    m_page->m_doc->m_imageData[m_ref] = img;
     return img;
 }
 
 QImage PdfImagePrivate::load()
 {
-    const auto it = m_page->m_doc->m_imageData.find(m_refNum);
+    const auto it = m_page->m_doc->m_imageData.find(m_ref);
     if (it != m_page->m_doc->m_imageData.end()) {
         return (*it).second;
     }
@@ -137,9 +153,27 @@ QImage PdfImagePrivate::load()
 
 #if KPOPPLER_VERSION >= QT_VERSION_CHECK(0, 69, 0)
     const auto xref = m_page->m_doc->m_popplerDoc->getXRef();
-    const auto obj = xref->fetch(m_refNum, m_refGen);
-    return load(obj.getStream(), m_colorMap.get());
+    const auto obj = xref->fetch(refNum(), refGen());
+
+    switch (m_ref.m_type) {
+        case PdfImageType::Image:
+            return load(obj.getStream(), m_colorMap.get());
+        case PdfImageType::Mask:
+        {
+            const auto dict = obj.getStream()->getDict();
+            const auto maskObj = dict->lookup("Mask");
+            return load(maskObj.getStream(), m_colorMap.get());
+        }
+        case PdfImageType::SMask:
+            return {}; // TODO
+    }
+
+    return {};
 #else
+    if (m_ref.m_type != PdfImageType::Image) {
+        return {};
+    }
+
     std::unique_ptr<ImageLoaderOutputDevice> device(new ImageLoaderOutputDevice(this));
     m_page->m_doc->m_popplerDoc->displayPageSlice(device.get(), m_page->m_pageNum + 1, 72, 72, 0, false, true, false, -1, -1, -1, -1);
     return device->image();
@@ -207,12 +241,12 @@ QImage PdfImage::image() const
 
 bool PdfImage::hasObjectId() const
 {
-    return d->m_refNum >= 0;
+    return !d->m_ref.isNull();
 }
 
-int PdfImage::objectId() const
+PdfImageRef PdfImage::objectId() const
 {
-    return d->m_refNum;
+    return d->m_ref;
 }
 
 bool PdfImage::isVectorImage() const
