@@ -4,19 +4,18 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#include "config-kitinerary.h"
 #include "icaldocumentprocessor.h"
 #include "logging.h"
 
+#include <KItinerary/Event>
 #include <KItinerary/ExtractorDocumentNodeFactory>
 #include <KItinerary/ExtractorEngine>
 #include <KItinerary/ExtractorFilter>
 #include <KItinerary/ExtractorResult>
+#include <KItinerary/Place>
 
-#ifdef HAVE_KCAL
 #include <KCalendarCore/ICalFormat>
 #include <KCalendarCore/MemoryCalendar>
-#endif
 
 #include <QJSEngine>
 #include <QJSValue>
@@ -52,7 +51,6 @@ bool IcalCalendarProcessor::canHandleData(const QByteArray &encodedData, QString
 
 ExtractorDocumentNode IcalCalendarProcessor::createNodeFromData(const QByteArray &encodedData) const
 {
-#ifdef HAVE_KCAL
     KCalendarCore::Calendar::Ptr calendar(new KCalendarCore::MemoryCalendar(QTimeZone::systemTimeZone()));
     KCalendarCore::ICalFormat format;
     if (format.fromRawString(calendar, encodedData)) {
@@ -63,48 +61,71 @@ ExtractorDocumentNode IcalCalendarProcessor::createNodeFromData(const QByteArray
     } else {
         qCDebug(Log) << "Failed to parse iCal content.";
     }
-#endif
     return {};
 }
 
 void IcalCalendarProcessor::expandNode(ExtractorDocumentNode &node, const ExtractorEngine *engine) const
 {
-#ifdef HAVE_KCAL
     const auto cal = node.content<KCalendarCore::Calendar::Ptr>();
     for (const auto &event : cal->events()) {
         auto child = engine->documentNodeFactory()->createNode(QVariant::fromValue(event), u"internal/event");
         node.appendChild(child);
     }
-#endif
 }
 
 
 bool IcalEventProcessor::matches(const ExtractorFilter &filter, const ExtractorDocumentNode &node) const
 {
-#ifdef HAVE_KCAL
-    const auto event = node.content<KCalCore::Event::Ptr>();
+    const auto event = node.content<KCalendarCore::Event::Ptr>();
     return matchesGadget(filter, event.data());
-#else
-    return false;
-#endif
 }
 
 void IcalEventProcessor::preExtract(ExtractorDocumentNode &node, [[maybe_unused]] const ExtractorEngine *engine) const
 {
-#ifdef HAVE_KCAL
-    const auto event = node.content<KCalCore::Event::Ptr>();
+    const auto event = node.content<KCalendarCore::Event::Ptr>();
     const auto data = event->customProperty("KITINERARY", "RESERVATION");
     if (!data.isEmpty()) {
         node.addResult(QJsonDocument::fromJson(data.toUtf8()).array());
     }
-#endif
+}
+
+void IcalEventProcessor::postExtract(ExtractorDocumentNode &node, const ExtractorEngine* engine) const
+{
+    if (!node.result().isEmpty() || (engine->hints() & ExtractorEngine::ExtractGenericIcalEvents) == 0) {
+        return;
+    }
+
+    const auto event = node.content<KCalendarCore::Event::Ptr>();
+    if (event->recurs() || event->hasRecurrenceId()) {
+        return;
+    }
+
+    Event e;
+    e.setName(event->summary());
+    e.setDescription(event->description());
+    e.setUrl(event->url());
+
+    if (event->allDay()) {
+        e.setStartDate(QDateTime(event->dtStart().date(), {0, 0}, Qt::LocalTime));
+        e.setEndDate(QDateTime(event->dtEnd().date(), {23, 59, 59}, Qt::LocalTime));
+    } else {
+        e.setStartDate(event->dtStart());
+        e.setEndDate(event->dtEnd());
+    }
+
+    Place venue;
+    venue.setName(event->location()); // TODO attempt to detect addresses in here
+    if (event->hasGeo()) {
+        venue.setGeo({event->geoLatitude(), event->geoLongitude()});
+    }
+    e.setLocation(venue);
+
+    // TODO attachments?
+
+    node.addResult(QVector<QVariant>{QVariant::fromValue(e)});
 }
 
 QJSValue IcalEventProcessor::contentToScriptValue(const ExtractorDocumentNode &node, QJSEngine *engine) const
 {
-#ifdef HAVE_KCAL
     return engine->toScriptValue(*node.content<KCalendarCore::Event::Ptr>().data());
-#else
-    return {};
-#endif
 }
